<?php

require_once("model/ColorStorage.php");
require_once("view/MainView.php");
require_once("ctl/Controller.php");


class Router {

	public function __construct(ColorStorage $colordb) {
		$this->colordb = $colordb;
	}

	public function main() {
		$view = new MainView($this);
		$ctl = new Controller($view, $this->colordb);

		/* Analyse de l'URL */
		$colorId = key_exists('couleur', $_GET)? $_GET['couleur']: null;
		$action = key_exists('action', $_GET)? $_GET['action']: null;
		if ($action === null) {
			/* Pas d'action demandée : par défaut on affiche
	 	 	 * la page d'accueil, sauf si une couleur est demandée,
	 	 	 * auquel cas on affiche sa page. */
			$action = ($colorId === null)? "accueil": "voir";
		}

		try {
			switch ($action) {
			case "voir":
				if ($colorId === null) {
					$view->makeUnknownActionPage();
				} else {
					$ctl->colorPage($colorId);
				}
				break;

			case "galerie":
				$ctl->allColorsPage();
				break;

			case "accueil":
				$view->makeHomePage();
				break;

			default:
				/* L'internaute a demandé une action non prévue. */
				$view->makeUnknownActionPage();
				break;
			}
		} catch (Exception $e) {
			/* Si on arrive ici, il s'est passé quelque chose d'imprévu
	 	 	 * (par exemple un problème de base de données) */
			$view->makeUnexpectedErrorPage($e);
		}

		/* Enfin, on affiche la page préparée */
		$view->render();
	}

	/* URL de la page d'accueil */
	public function homePage() {
		return ".";
	}

	/* URL de la page de la couleur d'identifiant $id */
	public function colorPage($id) {
		return ".?couleur=$id";
	}

	/* URL de la page avec toutes les couleurs */
	public function allColorsPage() {
		return ".?action=galerie";
	}

}

?>
